
Personis Server
===============

Personis operates as a library that is imported by application programs and stores models in the local file
system.

Personis can also be run as a server, providing an interface to models for remote clients. In this case the API is almost the same, the only difference being the modules that is imported and used for the Access call, and the specification of the model to be accessed. The server also adds authorization and authentication.

For details, see :doc:`Installation`.